Crate test_kms_server

Crate test_kms_server 

Re-exports

pub use vector_runner::run_test_vector;
pub use vector_runner::run_test_vector_with_context;

Modules

reexport
vector_runner

Structs

HsmConfig
MainDBConfig
Configuration for the database
TestClientOptions
Simplified client authentication options for test scenarios.
TestsContext

Constants

AUTH0_TOKEN
Long-lived Auth0 JWT for the tech@cosmian.com test account.
DEFAULT_SQLITE_PATH

Functions

hsm_config_path
Like test_config_path but resolves paths under the hsm/ sub-directory.
init_openssl_providers_for_tests
No-op for FIPS builds
init_test_logging
start_default_test_kms_server
Start a test KMS server in a thread with the default options: No TLS, no certificate authentication.
start_default_test_kms_server_with_cert_auth
TLS + certificate authentication.
start_default_test_kms_server_with_jwt_auth
Plain-HTTP server with JWT authentication enabled (Auth0 IdP).
start_default_test_kms_server_with_multi_privileged_users
Privileged users — two distinct identities in the list.
start_default_test_kms_server_with_non_revocable_key_ids
Non-revocable key IDs.
start_default_test_kms_server_with_privileged_users
Privileged users.
start_default_test_kms_server_with_softhsm2_and_kek
With SoftHSM2 HSM + KEK
start_default_test_kms_server_with_softhsm2_and_kek_for_vectors
Start a SoftHSM2 + KEK test server for use by the vector runner.
start_default_test_kms_server_with_three_softhsm2
Start a test KMS server with three SoftHSM2 instances:
start_default_test_kms_server_with_utimaco_and_kek
With Utimaco HSM
start_default_test_kms_server_with_utimaco_hsm
With Utimaco HSM
start_test_kms_server_with_config
Start a test KMS server in a thread with the default options: No TLS, no certificate authentication
start_test_server
Start a test server from a TOML config file with default client options.
start_test_server_from_toml
Start an isolated test KMS server from a TOML configuration file.
start_test_server_with_patch
Start a test server from a TOML config file, applying a runtime patch to the config.
test_config_path
Returns the absolute path to a test server TOML configuration file.