HsmConfig

Struct HsmConfig 

pub struct HsmConfig {
    pub hsm_model: String,
    pub hsm_admin: Vec<String>,
    pub hsm_slot: Vec<usize>,
    pub hsm_password: Vec<String>,
}

Fields

hsm_model: String

The HSM model. Trustway Proteccio, Trustway Crypt2pay, Utimaco General Purpose HSM, Smartcard HSM, and SoftHSM2 are natively supported. Other HSMs are supported too; specify other and check the documentation

hsm_admin: Vec<String>

List of KMS usernames that are granted HSM admin privileges. HSM admins can create, destroy, and potentially export objects on the HSM. Use "*" as the only entry to grant all authenticated users admin access. Repeat the option or use a comma-separated list to specify multiple admins: --hsm-admin alice@example.com --hsm-admin bob@example.com or set KMS_HSM_ADMIN=alice@example.com,bob@example.com

hsm_slot: Vec<usize>

HSM slot number. The slots used must be listed. Repeat this option to specify multiple slots while specifying a password for each slot (or an empty string for no password) e.g.

  --hsm-slot 1 --hsm-password password1 \
  --hsm-slot 2 --hsm-password password2
hsm_password: Vec<String>

Password for the user logging in to the HSM Slot specified with --hsm_slot Provide an empty string for no password see --hsm_slot for more information. Set KMS_HSM_PASSWORD to avoid the password appearing in ps output.

Implementations

Source

impl HsmConfig

pub fn slot_passwords(&self) -> HashMap<usize, Option<String>>

Build the slot_passwords map expected by BaseHsm::instantiate.