Re-exports
pub use vector_runner::run_test_vector;pub use vector_runner::run_test_vector_with_context;
Modules
Structs
- HsmConfig
- MainDB
Config - Configuration for the database
- Test
Client Options - Simplified client authentication options for test scenarios.
- Tests
Context
Constants
- AUTH0_
TOKEN - Long-lived Auth0 JWT for the
tech@cosmian.comtest account. - DEFAULT_
SQLITE_ PATH
Functions
- hsm_
config_ path - Like
test_config_pathbut resolves paths under thehsm/sub-directory. - init_
openssl_ providers_ for_ tests - No-op for FIPS builds
- init_
test_ logging - start_
default_ test_ kms_ server - Start a test KMS server in a thread with the default options: No TLS, no certificate authentication.
- start_
default_ test_ kms_ server_ with_ cert_ auth - TLS + certificate authentication.
- start_
default_ test_ kms_ server_ with_ jwt_ auth - Plain-HTTP server with JWT authentication enabled (Auth0
IdP). - start_
default_ test_ kms_ server_ with_ multi_ privileged_ users - Privileged users — two distinct identities in the list.
- start_
default_ test_ kms_ server_ with_ non_ revocable_ key_ ids - Non-revocable key IDs.
- start_
default_ test_ kms_ server_ with_ privileged_ users - Privileged users.
- start_
default_ test_ kms_ server_ with_ softhsm2_ and_ kek - With
SoftHSM2HSM + KEK - start_
default_ test_ kms_ server_ with_ softhsm2_ and_ kek_ for_ vectors - Start a
SoftHSM2+ KEK test server for use by the vector runner. - start_
default_ test_ kms_ server_ with_ three_ softhsm2 - Start a test KMS server with three
SoftHSM2instances: - start_
default_ test_ kms_ server_ with_ utimaco_ and_ kek - With Utimaco HSM
- start_
default_ test_ kms_ server_ with_ utimaco_ hsm - With Utimaco HSM
- start_
test_ kms_ server_ with_ config - Start a test KMS server in a thread with the default options: No TLS, no certificate authentication
- start_
test_ server - Start a test server from a TOML config file with default client options.
- start_
test_ server_ from_ toml - Start an isolated test KMS server from a TOML configuration file.
- start_
test_ server_ with_ patch - Start a test server from a TOML config file, applying a runtime patch to the config.
- test_
config_ path - Returns the absolute path to a test server TOML configuration file.