Crate test_kms_server

Crate test_kms_server 

Modules

reexport

Structs

AuthenticationOptions
BuildServerParamsOptions
Options container to avoid too_many_arguments on the builder
ClientAuthOptions
HsmConfig
MainDBConfig
Configuration for the database
TestsContext

Enums

ApiTokenPolicy
ClientCertPolicy
JwtPolicy
ServerJwtAuth
ServerTlsMode

Constants

DEFAULT_SQLITE_PATH

Functions

build_server_params
build_server_params_full
init_openssl_providers_for_tests
No-op for FIPS builds
init_test_logging
start_default_test_kms_server
Start a test KMS server in a thread with the default options: No TLS, no certificate authentication
start_default_test_kms_server_with_cert_auth
TLS + certificate authentication
start_default_test_kms_server_with_non_revocable_key_ids
revocable key IDs
start_default_test_kms_server_with_privileged_users
Privileged users
start_default_test_kms_server_with_utimaco_and_kek
With Utimaco HSM
start_default_test_kms_server_with_utimaco_hsm
With Utimaco HSM
start_test_kms_server_with_config
Start a test KMS server in a thread with the default options: No TLS, no certificate authentication
start_test_server_with_options
Start a KMS server in a thread with the given options