Modules
Structs
- Authentication
Options - Build
Server Params Options - Options container to avoid
too_many_argumentson the builder - Client
Auth Options - HsmConfig
- MainDB
Config - Configuration for the database
- Tests
Context
Enums
Constants
Functions
- build_
server_ params - build_
server_ params_ full - init_
openssl_ providers_ for_ tests - No-op for FIPS builds
- init_
test_ logging - start_
default_ test_ kms_ server - Start a test KMS server in a thread with the default options: No TLS, no certificate authentication
- start_
default_ test_ kms_ server_ with_ cert_ auth - TLS + certificate authentication
- start_
default_ test_ kms_ server_ with_ non_ revocable_ key_ ids - revocable key IDs
- start_
default_ test_ kms_ server_ with_ privileged_ users - Privileged users
- start_
default_ test_ kms_ server_ with_ utimaco_ and_ kek - With Utimaco HSM
- start_
default_ test_ kms_ server_ with_ utimaco_ hsm - With Utimaco HSM
- start_
test_ kms_ server_ with_ config - Start a test KMS server in a thread with the default options: No TLS, no certificate authentication
- start_
test_ server_ with_ options - Start a KMS server in a thread with the given options